Skip to contents

delete the local arkdb database

Usage

arkdb_delete_db(db_dir = arkdb_dir(), ask = interactive())

Arguments

db_dir

neon database location

ask

Ask for confirmation first?

Details

Just a helper function that deletes the database files. Usually unnecessary but can be helpful in resetting a corrupt database.

Examples


# Create a db
dir <- tempfile()
db <- local_db(dir)
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#>  /tmp/RtmpEkbx6V/duckdb
#> This is removed when the R session ends.
#>  Extensions are re-downloaded each session.
#>  Secrets are lost.
#>  Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#>  Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#>  See ?duckdb_storage for details and alternatives.

# Delete it
arkdb_delete_db(dir, ask = FALSE)