powered by
Disconnect from the arkdb database.
local_db_disconnect(db = local_db(), env = arkdb_cache)
a DBI connection. By default, will call local_db for the default connection.
The environment where the function looks for a connection.
This function manually closes a connection to the arkdb database.
arkdb
# \donttest{ ## Disconnect from the database: local_db_disconnect() # }
Run the code above in your browser using DataLab