delete the local arkdb database
Usage
arkdb_delete_db(db_dir = arkdb_dir(), ask = interactive())Details
Just a helper function that deletes the database files. Usually unnecessary but can be helpful in resetting a corrupt database.
Examples
# Create a db
dir <- tempfile()
db <- local_db(dir)
#> duckdb: caching downloaded extensions in the package library:
#> ℹ /github/home/R/x86_64-pc-linux-gnu-library/4.6/duckdb/extensions
#> ℹ This is removed when the package is re-installed; see `?duckdb_storage` to choose a different location.
# Delete it
arkdb_delete_db(dir, ask = FALSE)